@@ -15,7 +15,7 @@ impl<'src> Justfile<'src> {
     for recipe in self.recipes.values() {
       if let Some(first_recipe) = first {
         if recipe.line_number() < first_recipe.line_number() {
-          first = Some(recipe)
+          first = Some(recipe);
         }
       } else {
         first = Some(recipe);
@@ -127,34 +127,70 @@ impl<'src> Justfile<'src> {
       )?
     };
 
-    if let Subcommand::Evaluate { variable, .. } = &config.subcommand {
-      if let Some(variable) = variable {
-        if let Some(value) = scope.value(variable) {
-          print!("{}", value);
+    match &config.subcommand {
+      Subcommand::Command {
+        binary, arguments, ..
+      } => {
+        let mut command = if config.shell_command {
+          let mut command = self.settings.shell_command(&config);
+          command.arg(binary);
+          command
         } else {
-          return Err(RuntimeError::EvalUnknownVariable {
-            suggestion: self.suggest_variable(&variable),
-            variable:   variable.to_owned(),
-          });
-        }
-      } else {
-        let mut width = 0;
+          Command::new(binary)
+        };
 
-        for name in scope.names() {
-          width = cmp::max(name.len(), width);
+        command.args(arguments);
+
+        command.current_dir(&search.working_directory);
+
+        let scope = scope.child();
+
+        command.export(&self.settings, &dotenv, &scope);
+
+        let status = InterruptHandler::guard(|| command.status()).map_err(|io_error| {
+          RuntimeError::CommandInvocation {
+            binary: binary.clone(),
+            arguments: arguments.clone(),
+            io_error,
+          }
+        })?;
+
+        if !status.success() {
+          process::exit(status.code().unwrap_or(EXIT_FAILURE));
+        };
+
+        return Ok(());
+      },
+      Subcommand::Evaluate { variable, .. } => {
+        if let Some(variable) = variable {
+          if let Some(value) = scope.value(variable) {
+            print!("{}", value);
+          } else {
+            return Err(RuntimeError::EvalUnknownVariable {
+              suggestion: self.suggest_variable(&variable),
+              variable:   variable.clone(),
+            });
+          }
+        } else {
+          let mut width = 0;
+
+          for name in scope.names() {
+            width = cmp::max(name.len(), width);
+          }
+
+          for binding in scope.bindings() {
+            println!(
+              "{0:1$} := \"{2}\"",
+              binding.name.lexeme(),
+              width,
+              binding.value
+            );
+          }
         }
 
-        for binding in scope.bindings() {
-          println!(
-            "{0:1$} := \"{2}\"",
-            binding.name.lexeme(),
-            width,
-            binding.value
-          );
-        }
-      }
-
-      return Ok(());
+        return Ok(());
+      },
+      _ => {},
     }
 
     let argvec: Vec<&str> = if !arguments.is_empty() {
@@ -224,7 +260,7 @@ impl<'src> Justfile<'src> {
 
     let mut ran = BTreeSet::new();
     for (recipe, arguments) in grouped {
-      self.run_recipe(&context, recipe, arguments, &dotenv, &search, &mut ran)?
+      self.run_recipe(&context, recipe, arguments, &dotenv, &search, &mut ran)?;
     }
 
     Ok(())
@@ -235,13 +271,11 @@ impl<'src> Justfile<'src> {
   }
 
   pub(crate) fn get_recipe(&self, name: &str) -> Option<&Recipe<'src>> {
-    if let Some(recipe) = self.recipes.get(name) {
-      Some(recipe)
-    } else if let Some(alias) = self.aliases.get(name) {
-      Some(alias.target.as_ref())
-    } else {
-      None
-    }
+    self
+      .recipes
+      .get(name)
+      .map(Rc::as_ref)
+      .or_else(|| self.aliases.get(name).map(|alias| alias.target.as_ref()))
   }
 
   fn run_recipe<'run>(
@@ -599,9 +633,9 @@ mod tests {
     "#,
     args: ["--quiet", "wut"],
     error: Code {
-      code: _,
       line_number,
       recipe,
+      ..
     },
     check: {
       assert_eq!(recipe, "wut");
